==> popular_tags-2.0.0.tar.gz: popular_tags/src/PopularTagsHelper.php <==
<?php

namespace Drupal\popular_tags;

/**
 * Class PopularTagsHelper. Helper class to add the popular tags functionality.
 *
 * @package Drupal\popular_tags
 */
abstract class PopularTagsHelper {

  /**
   * Utilty function to inject the popular tags functionality into a form element.
   *
   * @param array $element
   *   Form element.
   * @param array $context
   *   Form element context.
   */
  public static function inject(&$element, $context) {
    $element['#attached']['library'][] = 'popular_tags/popular_tags';
    $field_definition = $context['items']->getFieldDefinition();
    $field_name = $field_definition->getName();
    $vocabs = $field_definition->getSetting('handler_settings')['target_bundles'];

    // Popular Tags settings will be stored in third_party_settings.
    $settings = $context['widget']->getThirdPartySettings('popular_tags');
    $limit = $settings['popular_tags']['limit'] ?? 5;
    $showhide = $settings['popular_tags']['showhide'] ?? FALSE;

    if ($showhide) {
      $data['popular_tags'][$field_name]['limit'] = $limit;
      $element['#attached']['drupalSettings'] = $data;
    }

    if (!empty($limit) && !empty($showhide)) {
      $classes[] = 'popular';
    }

    $terms = self::getTerms($vocabs, $limit, $showhide);
    $tag_terms = '<div class="tag-terms">';
    $classes[] = 'term';

    $count = 0;
    foreach ($terms as $tid => $term) {
      $count++;
      if (!empty($limit) && !empty($showhide) && $count > $limit) {
        $key = array_search('popular', $classes);
        if ($key !== FALSE) {
          unset($classes[$key]);
        }
      }

      // A term name containing a comma needs to be quoted.
      if (strpos($term->name, ',') !== FALSE) {
        $term->name = '"' . $term->name . '"';
      }

      $tag_terms .= t('<a class="@classes" data-usage="@freq" data-tid="@tid">@term</a>', [
        '@term' => $term->name,
        '@freq' => $term->freq,
        '@tid' => $term->tid,
        '@classes' => implode(' ', $classes),
      ]);
    }
    $tag_terms .= '</div>';
    $html = '<div class="popular-tags">' . t('You can type your own tags, or choose from the most commonly used tags below.');
    if (!empty($limit) && !empty($showhide)) {
      $html .= '<a class="show-all-terms">' . t('Show All Terms') . '</a>';
      $html .= '<a class="show-popular-terms">' . t('Show Popular Terms') . '</a>';
    }
    $html .= $tag_terms . '</div>';
    $element['target_id']['#description'] = isset($element['#description']) ? $element['#description'] . $html : $html;
  }

  /**
   * Helper function find and return most popular tags.
   */
  protected static function getTerms($vocabs, $limit = NULL, $all = FALSE) {
    $query = \Drupal::database()->select('taxonomy_term_data', 'td');
    $query->fields('td', ['tid']);
    $query->leftJoin('taxonomy_index', 'tn', 'tn.tid = td.tid');
    $query->leftJoin('taxonomy_term_field_data', 'ttfd', 'td.tid = ttfd.tid');
    $query->fields('ttfd', ['name']);
    $query->addExpression('COUNT(tn.tid)', 'freq');
    $query->condition('td.vid', $vocabs, 'IN');
    $query->groupBy('td.tid')
      ->groupBy('ttfd.name')
      ->orderBy('freq', 'DESC')
      ->orderBy('name');
    if (!empty($limit) && !$all) {
      $query->range(0, $limit);
    }
    $terms = $query->execute()->fetchAllAssoc('tid');
    return $terms;
  }

}

==> popular_tags-2.1.0.tar.gz: popular_tags/src/PopularTagsHelper.php <==
<?php

namespace Drupal\popular_tags;

/**
 * Class PopularTagsHelper. Helper class to add the popular tags functionality.
 *
 * @package Drupal\popular_tags
 */
abstract class PopularTagsHelper {

  /**
   * Utilty function to inject the popular tags functionality
   * into a form element.
   *
   * @param array $element
   *   Form element.
   * @param array $context
   *   Form element context.
   */
  public static function inject(&$element, $context) {
    $element['#attached']['library'][] = 'popular_tags/popular_tags';
    $field_definition = $context['items']->getFieldDefinition();
    $field_name = $field_definition->getName();
    $vocabs = $field_definition->getSetting('handler_settings')['target_bundles'];

    // Popular Tags settings will be stored in third_party_settings.
    $settings = $context['widget']->getThirdPartySettings('popular_tags');
    $limit = $settings['popular_tags']['limit'] ?? 5;
    $showhide = $settings['popular_tags']['showhide'] ?? FALSE;

    if ($showhide) {
      $data['popular_tags'][$field_name]['limit'] = $limit;
      $element['#attached']['drupalSettings'] = $data;
    }

    if (!empty($limit) && !empty($showhide)) {
      $classes[] = 'popular';
    }

    $terms = self::getTerms($vocabs, $limit, $showhide);
    $tag_terms = '<div class="tag-terms">';
    $classes[] = 'term';

    $count = 0;
    foreach ($terms as $tid => $term) {
      $count++;
      if (!empty($limit) && !empty($showhide) && $count > $limit) {
        $key = array_search('popular', $classes);
        if ($key !== FALSE) {
          unset($classes[$key]);
        }
      }

      // A term name containing a comma needs to be quoted.
      if (strpos($term->name, ',') !== FALSE) {
        $term->name = '"' . $term->name . '"';
      }

      $tag_terms .= t('<a class="@classes" data-usage="@freq" data-tid="@tid">@term</a>', [
        '@term' => $term->name,
        '@freq' => $term->freq,
        '@tid' => $term->tid,
        '@classes' => implode(' ', $classes),
      ]);
    }
    $tag_terms .= '</div>';
    $html = '<div class="popular-tags">' . t('You can type your own tags, or choose from the most commonly used tags below.');
    if (!empty($limit) && !empty($showhide)) {
      $html .= '<a class="show-all-terms">' . t('Show All Terms') . '</a>';
      $html .= '<a class="show-popular-terms">' . t('Show Popular Terms') . '</a>';
    }
    $html .= $tag_terms . '</div>';
    $element['target_id']['#description'] = isset($element['#description']) ? $element['#description'] . $html : $html;
  }

  /**
   * Helper function find and return most popular tags.
   */
  protected static function getTerms($vocabs, $limit = NULL, $all = FALSE) {
    $query = \Drupal::database()->select('taxonomy_term_data', 'td');
    $query->fields('td', ['tid']);
    $query->leftJoin('taxonomy_index', 'tn', 'tn.tid = td.tid');
    $query->leftJoin('taxonomy_term_field_data', 'ttfd', 'td.tid = ttfd.tid');
    $query->fields('ttfd', ['name']);
    $query->addExpression('COUNT(tn.tid)', 'freq');
    $query->condition('td.vid', $vocabs, 'IN');
    $query->groupBy('td.tid')
      ->groupBy('ttfd.name')
      ->orderBy('freq', 'DESC')
      ->orderBy('name');
    if (!empty($limit) && !$all) {
      $query->range(0, $limit);
    }
    $terms = $query->execute()->fetchAllAssoc('tid');
    return $terms;
  }

}
